#ifndef NT2_INCLUDE_FUNCTIONS_EXPNI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_EXPNI_HPP_INCLUDED

#include <nt2/euler/include/functions/expni.hpp>

#endif
